import math


def add(a, b, c):
    return a + b + c


def sub(a, b):
    return b - a


def mult(a, b):
    return a * b


def div(a, b):
    return math.ceil(a / b)


def floordiv(a, b):
    return a // b
